@@ -138,7 +138,7 @@ pub struct Method {
     pub response_payload: bool,
 }
 
-pub trait AnyRequest: Serialize + Sized + 'static {
+pub trait AnyRequest: Serialize + Sized + std::fmt::Debug + 'static {
     type Response: Serialize + 'static;
     fn from_method_and_params(method: &str, params: &RawValue) -> Result<Self, Error>;
     fn response_from_method_and_result(
@@ -222,7 +222,7 @@ macro_rules! acp_peer {
             fn response_from_any(any: $response_enum_name) -> Result<Self::Response, Error>;
         }
 
-        #[derive(Serialize, JsonSchema)]
+        #[derive(Serialize, JsonSchema, Debug)]
         #[serde(untagged)]
         pub enum $request_enum_name {
             $(
@@ -400,6 +400,14 @@ acp_peer!(
         UpdateToolCallResponse,
         false
     ),
+    (
+        update_plan,
+        "updatePlan",
+        UpdatePlanParams,
+        true,
+        UpdatePlanResponse,
+        false
+    ),
     (
         write_text_file,
         "writeTextFile",
@@ -415,7 +423,7 @@ acp_peer!(
         true,
         ReadTextFileResponse,
         true
-    )
+    ),
 );
 
 // requests sent from the agent to the client (the IDE)
@@ -702,6 +710,58 @@ pub struct UpdateToolCallParams {
 #[derive(Debug, Serialize, Deserialize, JsonSchema)]
 pub struct UpdateToolCallResponse;
 
+/// Parameters for updating the current execution plan.
+///
+/// This allows the assistant to communicate its high-level plan
+/// for completing the user's request.
+#[derive(Debug, Serialize, Deserialize, JsonSchema)]
+#[serde(rename_all = "camelCase")]
+pub struct UpdatePlanParams {
+    /// The list of plan entries representing the current execution plan.
+    pub entries: Vec<PlanEntry>,
+}
+
+#[derive(Debug, Serialize, Deserialize, JsonSchema)]
+pub struct UpdatePlanResponse;
+
+/// A single entry in the execution plan.
+///
+/// Represents a task or goal that the assistant intends to accomplish
+/// as part of fulfilling the user's request.
+#[derive(Debug, Serialize, Deserialize, JsonSchema)]
+#[serde(rename_all = "camelCase")]
+pub struct PlanEntry {
+    /// Description of what this task aims to accomplish
+    pub content: String,
+    /// Relative importance of this task
+    pub priority: PlanEntryPriority,
+    /// Current progress of this task
+    pub status: PlanEntryStatus,
+}
+
+/// Priority levels for plan entries.
+///
+/// Used to indicate the relative importance or urgency of different
+/// tasks in the execution plan.
+#[derive(Deserialize, Serialize, JsonSchema, Debug)]
+#[serde(rename_all = "snake_case")]
+pub enum PlanEntryPriority {
+    High,
+    Medium,
+    Low,
+}
+
+/// Status of a plan entry in the execution flow.
+///
+/// Tracks the lifecycle of each task from planning through completion.
+#[derive(Deserialize, Serialize, JsonSchema, Debug)]
+#[serde(rename_all = "snake_case")]
+pub enum PlanEntryStatus {
+    Pending,
+    InProgress,
+    Completed,
+}
+
 #[derive(Debug, Serialize, Deserialize, JsonSchema)]
 #[serde(rename_all = "camelCase")]
 pub enum ToolCallStatus {
